@@ -312,6 +312,7 @@ compute_sentiment.sento_corpus <- compiler::cmpfun(.compute_sentiment.sento_corp
   } else {
     isNumeric <- sapply(quanteda::docvars(x), is.numeric)
     if (sum(isNumeric) == 0) features <- NULL else features <- names(isNumeric[isNumeric])
+    check_feature_names(features) # check if feature names will not give duplicate columns
     dv <- data.table::as.data.table(quanteda::docvars(x)[features])
   }
 
@@ -507,7 +508,7 @@ peakdocs <- function(sentiment, n = 10, type = "both", do.average = FALSE) {
     ids <- sentiment[["id"]]
   } else ids <- rep(sentiment[["id"]], m)
   if (type == "both") s <- abs(s)
-  indx <- order(s, decreasing = ifelse(type == "neg", FALSE, TRUE))[1:(m * n)]
+  indx <- order(unlist(s), decreasing = ifelse(type == "neg", FALSE, TRUE))[1:(m * n)]
   peakIds <- unique(ids[indx])[1:n]
   peakIds
 }
